@@ -189,10 +189,11 @@ extern globus_bool_t                    globus_i_gssapi_active;
                     "%s exiting\n", \
                     __func__))
 
-extern int                        globus_i_gsi_gssapi_min_tls_protocol;
-extern int                        globus_i_gsi_gssapi_max_tls_protocol;
+extern int                              globus_i_gsi_gssapi_min_tls_protocol;
+extern int                              globus_i_gsi_gssapi_max_tls_protocol;
 extern const char *                     globus_i_gsi_gssapi_cipher_list;
 extern globus_bool_t                    globus_i_gsi_gssapi_server_cipher_order;
+extern uid_t                            globus_i_gsi_gssapi_vhost_cred_owner;
 
 typedef enum
 {
@@ -211,6 +212,7 @@ globus_i_gsi_gss_create_and_fill_context(
     OM_uint32 *                         minor_status,
     gss_ctx_id_desc **                  context_handle,
     gss_OID                             mech,
+    const gss_name_t                    target_name,
     gss_cred_id_desc *                  cred_handle,
     const gss_cred_usage_t              cred_usage,
     OM_uint32                           req_flags);
@@ -240,7 +242,8 @@ globus_i_gsi_gss_create_cred(
     OM_uint32 *                         minor_status,
     const gss_cred_usage_t              cred_usage,
     gss_cred_id_t *                     output_cred_handle_P,
-    globus_gsi_cred_handle_t *          cred_handle);
+    globus_gsi_cred_handle_t *          cred_handle,
+    globus_bool_t                       sni_context);
 
 int globus_i_gsi_gss_verify_extensions_callback(
     globus_gsi_callback_data_t          callback_data,
@@ -295,7 +298,8 @@ OM_uint32
 globus_i_gsi_gssapi_init_ssl_context(
     OM_uint32 *                         minor_status,
     gss_cred_id_t                       credential,
-    globus_i_gsi_gss_context_type_t     anon_ctx);
+    globus_i_gsi_gss_context_type_t     anon_ctx,
+    globus_bool_t                       sni_context);
 
 globus_result_t
 globus_i_gsi_gssapi_openssl_error_result(
@@ -335,6 +339,12 @@ globus_i_gsi_gssapi_get_hostname(
     OM_uint32 *                         minor_status,
     gss_name_desc *                     name);
 
+OM_uint32
+globus_i_gss_read_vhost_cred_dir(
+    OM_uint32                          *minor_status,
+    const char                         *dirname,
+    gss_cred_id_t                     **output_credentials_array,
+    size_t                             *output_credentials_array_count);
 
 typedef enum
 {
